<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../about.ui" line="47"/>
        <source>Packet Sender</source>
        <translation>Packet Sender</translation>
    </message>
    <message>
        <location filename="../about.ui" line="136"/>
        <source>Written by Dan Nagle and published by NagleCode, LLC</source>
        <translation>Scritto da Dan Nagle e pubblicato da NagleCode, LLC</translation>
    </message>
    <message>
        <location filename="../about.ui" line="165"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../about.ui" line="185"/>
        <source>PacketSender.com</source>
        <translation>PacketSender.com</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="26"/>
        <source>
Commit Hash: </source>
        <translation>
Commit Hash: </translation>
    </message>
    <message>
        <location filename="../about.cpp" line="31"/>
        <source>About Packet Sender</source>
        <translation>About Packet Sender</translation>
    </message>
</context>
<context>
    <name>BruceThePoodle</name>
    <message>
        <location filename="../brucethepoodle.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../brucethepoodle.cpp" line="29"/>
        <source>Bruce The Poodle!</source>
        <translation>Bruce il barboncino!</translation>
    </message>
</context>
<context>
    <name>CloudUI</name>
    <message>
        <location filename="../cloudui.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="28"/>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="49"/>
        <source>Packet Sender Cloud</source>
        <translation>Packet Sender Cloud</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="73"/>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="91"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="112"/>
        <source>Confirm Password</source>
        <translation>Conferma Password</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="131"/>
        <source>Remember Login</source>
        <translation>Ricordami</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="140"/>
        <location filename="../cloudui.cpp" line="466"/>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="150"/>
        <location filename="../cloudui.cpp" line="465"/>
        <source>Create a new account.</source>
        <translation>Crea un nuovo account.</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="187"/>
        <source>Privacy</source>
        <translation>Privacy</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="194"/>
        <source>Terms</source>
        <translation>Termini</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="214"/>
        <source>cloud.packetsender.com/help</source>
        <translation>cloud.packetsender.com/help</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="228"/>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="239"/>
        <source>Import From URL</source>
        <translation>Importa da un URL</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="248"/>
        <location filename="../cloudui.ui" line="372"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="283"/>
        <source>Delete Packet Set</source>
        <translation>Elimina set di dati</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="268"/>
        <source>View URL</source>
        <translation>Ver URL</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="290"/>
        <source>Import Packet Set</source>
        <translation>Importa set di dati</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="307"/>
        <source>Save / Share</source>
        <translation>Salva / Condividi</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="313"/>
        <source>You are sharing.</source>
        <translation>Stai condividendo.</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="322"/>
        <source>Packet Set Name</source>
        <translation>Nome del pacchetto di dati</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="336"/>
        <source>Public Path</source>
        <translation>Percorso pubblico</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="359"/>
        <source>Make Public</source>
        <translation>Rendi Pubblico</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="401"/>
        <source>Save to Packet Sender Cloud</source>
        <translation>Salva in Packet Sender Cloud</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="83"/>
        <source>Cloud</source>
        <translation>Cloud</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source>Saving </source>
        <translation>Salvataggio</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source> packet set to cloud</source>
        <translation> pacchetto impostato su cloud</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="470"/>
        <source>Login instead.</source>
        <translation>Inizia sezione.</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="471"/>
        <source>Sign-up</source>
        <translation>Registrazione</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="528"/>
        <source>Delete Set</source>
        <translation>Elimina Set</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source>Delete the set </source>
        <translation>Elimina il set </translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source> from cloud?</source>
        <translation> da Cloud?</translation>
    </message>
</context>
<context>
    <name>IrisAndMarigold</name>
    <message>
        <location filename="../irisandmarigold.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
</context>
<context>
    <name>LanguageChooser</name>
    <message>
        <location filename="../languagechooser.ui" line="14"/>
        <source>Choose Language</source>
        <translation>Scegli lingua</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="46"/>
        <source>Español</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="79"/>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="115"/>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="187"/>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="206"/>
        <source>OK / Aceptar</source>
        <translation>OK / Aceptar / Accetta</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="151"/>
        <source>Français</source>
        <translation>Français</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="35"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="48"/>
        <source>Packet Name</source>
        <translation>Nome del Pacchetto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Request</source>
        <translation>Richiedi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>URL path</source>
        <translation>percorso URL</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Generate Data</source>
        <translation>Genera Dati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>ASCII representation</source>
        <translation>Rappresentazione ASCII</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Load File</source>
        <translation>Carica File</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>HEX</source>
        <translation>HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>HEX representation</source>
        <translation>Rappresentazione HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>IPv4, IPv6, DNS Lookup</source>
        <translation>Ricerca IPv4, IPv6, DNS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>1 to 65535</source>
        <translation>1 a 65535</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>0.0/blank off</source>
        <translation>0.0/disattivare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>TCP</source>
        <translation>TCP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>UDP</source>
        <translation>UDP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>SSL</source>
        <translation>SSL</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>HTTP Get</source>
        <translation>HTTP Get</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>HTTP Post</source>
        <translation>HTTP Post</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>HTTPS Get</source>
        <translation>HTTPS Get</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>HTTPS Post</source>
        <translation>HTTPS Post</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.cpp" line="1074"/>
        <location filename="../mainwindow.cpp" line="1732"/>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Search Saved Packets...</source>
        <translation>Cerca Pacchetti Salvati...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="360"/>
        <source>Generate Panel!</source>
        <translation>Genera Pannello!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Resend Delay</source>
        <translation>Ritardo di reinvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Delete Saved Packet</source>
        <translation>Elimina Pacchetto Salvato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>Persistent TCP</source>
        <translation>TCP Persistente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>Clear Log</source>
        <translation>Cancella Log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Log Traffic</source>
        <translation>Log Traffico</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Save Log</source>
        <translation>Salva Log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Save Traffic Packet</source>
        <translation>Salva Traffico dei Pacchetti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>Copy to Clipboard</source>
        <translation>Copia negli Appunti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="528"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>&amp;Tools</source>
        <translation>&amp;Strumenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>&amp;Multicast</source>
        <translation>&amp;Multicast</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>Panels</source>
        <translation>Páneles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>E&amp;xit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="581"/>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>&amp;About</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>&amp;Import Database</source>
        <translation>Importa Database</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>&amp;Export Database</source>
        <translation>Esporta Database</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Persistent Connection</source>
        <translation>Connessione Persistente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="622"/>
        <source>&amp;Subnet Calculator</source>
        <translation>Calcolatrice di Subnet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>D&amp;onate (Thank You!)</source>
        <translation>Donare (Grazie!)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="636"/>
        <source>Documentation</source>
        <translation>Documentazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Documentazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="650"/>
        <source>Export To Cloud</source>
        <translation>Esporta a Cloud</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>&amp;Cloud Save and Share</source>
        <translation>Salva e Condividi nel Cloud</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>&amp;Join/Leave IPv4</source>
        <translation>Unisci/Lascia IPv4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Android App</source>
        <translation>Android App</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>iOS App</source>
        <translation>iOS App</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Follow on Twitter</source>
        <translation>Segui su Twitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <source>Connect on LinkedIn</source>
        <translation>Connetti su LinkedIn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>Intense &amp;Traffic Generator</source>
        <translation>Generatore di Traffico Intenso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>Forums</source>
        <translation>Forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="727"/>
        <source>Load Starter Panel</source>
        <translation>Carica Pannello Iniziale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Empty Panel Project</source>
        <translation>Pulisci il Progetto Pannello</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="741"/>
        <source>Wake-On-LAN / Magic Packet</source>
        <translation>Wake-On-LAN</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Updates.</source>
        <translation>Aggiorna.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>There is a new Packet Sender available.

Download?</source>
        <translation>C&apos;è una nuova versione di Packet Sender.

Scarica?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Let Packet Sender check for updates weekly?</source>
        <translation>Consenti di verificare gli aggiornamenti di Packet Sender ogni settimana?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Packet Sender Updated!</source>
        <translation>Packet Sender aggiornato!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Updated to </source>
        <translation>Aggiornato a </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>!

Would you like to read the release notes?</source>
        <translation>!

Vuoi vedere le note di rilascio?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="735"/>
        <source>Clear Log </source>
        <translation>Cancella Log</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <location filename="../mainwindow.cpp" line="782"/>
        <location filename="../mainwindow.cpp" line="803"/>
        <source> Ports</source>
        <translation>Porte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="788"/>
        <source>SSL Server Disabled</source>
        <translation>Server SSL disabilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <source>TCP Server Disabled</source>
        <translation>Server TCP disabilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1030"/>
        <location filename="../mainwindow.cpp" line="1271"/>
        <source>Multicast detected.</source>
        <translation>Rilevato multicast</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1034"/>
        <source>Do you wish to join the multicast group?</source>
        <translation>Vuoi unirti al gruppo multicast?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1050"/>
        <location filename="../mainwindow.cpp" line="1293"/>
        <source>Broadcast with responses!</source>
        <translation>Trasmetti con cautela!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <source>You are sending a broadcast packet with responses enabled.

This could cause traffic flooding. Continue?</source>
        <translation>Stai inviando un pacchetto broadcast con risposta abilitata.

Questo può causare un intasamento di traffico dati. Continua?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <location filename="../mainwindow.cpp" line="1068"/>
        <location filename="../mainwindow.cpp" line="1333"/>
        <location filename="../mainwindow.cpp" line="1939"/>
        <source>Resending</source>
        <translation>Reinviando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="766"/>
        <source>UDP Server Disabled</source>
        <translation>Server UDP disabilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1074"/>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1101"/>
        <source>Name cannot be blank.</source>
        <translation>Il nome non può essere vuoto.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1105"/>
        <source>Name is empty.</source>
        <translation>Il nome è vuoto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1155"/>
        <source>This computer does not support SSL.

Expected SSL:</source>
        <translation>Questo computer non supporta SSL.

SSL richiesto:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1159"/>
        <source>No SSL Library.</source>
        <translation>Manca libreria SSL</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1212"/>
        <source>Address cannot be blank.</source>
        <translation>L&apos;indirizzo non può essere vuoto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1216"/>
        <source>Address is empty.</source>
        <translation>L&apos;indirizzo è vuoto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <source>Port cannot be blank/zero.</source>
        <translation>La porta non può essere vuota/zero</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1231"/>
        <source>Port is zero.</source>
        <translation>La porta è zero</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1245"/>
        <source>IPv6?</source>
        <translation>IPv6?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1249"/>
        <source>Enable IPv6 support?</source>
        <translation>Abilita Porta IPv6?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1275"/>
        <source>Join UDP multicast group?</source>
        <translation>Unisci al Gruppo Multicast UDP?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1313"/>
        <source>Resend TCP with persistent connections!</source>
        <translation>Reinvia TCP con connessione persistente!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1317"/>
        <source>You are resending a TCP packet with persistent connections. The UI could spawn numerous windows! 

Uncheck persistent connection? (Recommended)</source>
        <translation>Stai reinviando un Pacchetto TCP con connessione persistente. L&apos;interfaccia potrebbe aprire numerose finestre.

Disabilitare la Connessione persistente? (Raccomandato)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1352"/>
        <location filename="../mainwindow.cpp" line="2002"/>
        <source>No packets selected.</source>
        <translation>Non ci sono Pacchetti selezionati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1356"/>
        <source>Select a packet.</source>
        <translation>Seleziona un Pacchetto.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1395"/>
        <source>Invalid Address / DNS failed</source>
        <translation>Indirizzo non valido / Errore di DNS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1418"/>
        <source>Invalid Port</source>
        <translation>Porta non valida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1862"/>
        <source>Clear Log (0)</source>
        <translation>Pulisci Log (0)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1881"/>
        <source>Save Packet</source>
        <translation>Salva Pacchetto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1882"/>
        <source>Packet name:</source>
        <translation>Nome del Pacchetto:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2006"/>
        <source>Clipboard unchanged.</source>
        <translation>Appunti invariati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2067"/>
        <source>Save Traffic Log</source>
        <translation>Salva Log di Traffico</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>log (*.log)</source>
        <translation>Log (*.log)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>TIME</source>
        <translation>TEMPO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>From IP</source>
        <translation>Da IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>From Port</source>
        <translation>Da Porta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>To IP</source>
        <translation>A IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>To Port</source>
        <translation>A Porta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2262"/>
        <source>Import JSON</source>
        <translation>Importa JSON</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2264"/>
        <location filename="../mainwindow.cpp" line="2331"/>
        <source>JSON db (*.json)</source>
        <translation>db JSON (*.json)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source>Found </source>
        <translation>Trovato </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source> packets!</source>
        <translation> Pacchetti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source>Import </source>
        <translation>Importa </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source> packets?

Packet Sender will overwrite packets with the same name.</source>
        <translation> Pacchetti?

Packet Sender sovrascriverà i Pacchetti con lo stesso Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2295"/>
        <location filename="../mainwindow.cpp" line="2316"/>
        <location filename="../mainwindow.cpp" line="2432"/>
        <location filename="../mainwindow.cpp" line="2453"/>
        <source>Import Cancelled</source>
        <translation>Importazione Annullata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2303"/>
        <source>Import Finished</source>
        <translation>Importazione Conclusa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2309"/>
        <location filename="../mainwindow.cpp" line="2446"/>
        <source>Not a database</source>
        <translation>Non è un Database</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2313"/>
        <location filename="../mainwindow.cpp" line="2450"/>
        <source>Found no packets in this file. It may not be a Packet Sender export</source>
        <translation>Pacchetti non trovati in questo File. Potrebbe non essere una esportazione di Packet Sender</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2330"/>
        <source>Save JSON</source>
        <translation>Salva JSON</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2485"/>
        <source>Export: </source>
        <translation>Esporta: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2356"/>
        <source>Could not save</source>
        <translation>Non si può salvare</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2360"/>
        <source>Could not open </source>
        <translation>Non si può aprire </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2406"/>
        <location filename="../mainwindow.cpp" line="2531"/>
        <source>Import File</source>
        <translation>Importa File</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2408"/>
        <location filename="../mainwindow.cpp" line="2463"/>
        <source>INI db (*.ini)</source>
        <translation>db INI (*.ini)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2462"/>
        <source>Save File</source>
        <translation>Salva File</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2533"/>
        <source>*.*</source>
        <translation>*.*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2557"/>
        <source>Max size exceeded!</source>
        <translation>Dimensione massima superata!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2561"/>
        <source>The HEX field supports up to 10,922 bytes. The data has been truncated.</source>
        <translation>Il campo HEX supporta fino a 10.922 bytes. I dati sono stati troncati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2567"/>
        <source>Loading </source>
        <translation>Caricando </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2567"/>
        <source> bytes</source>
        <translation> bytes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2801"/>
        <source>Invalid MAC Address.</source>
        <translation>Indirizzo MAC non valido.</translation>
    </message>
</context>
<context>
    <name>MulticastSetup</name>
    <message>
        <location filename="../multicastsetup.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="22"/>
        <source>IP Multicast Address</source>
        <translation>Indirizzo IP Multicast</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="29"/>
        <source>Join</source>
        <translation>Entra</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="54"/>
        <source>Leave All Groups</source>
        <translation>Esci da tutti i gruppi</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="15"/>
        <source>IPv4 Multicast Setup (Experimental)</source>
        <translation>Configurazione Multicast IPv4 (Sperimentale)</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="31"/>
        <source>There are no bound UDP ports</source>
        <translation>Non sono presenti porte UDP vincolate</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="34"/>
        <source>UDP socket bound to </source>
        <translation>Socket UDP vincolato a </translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="36"/>
        <source> will join the multicast group</source>
        <translation> si unirá al Gruppo Multicast</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="59"/>
        <source>Not Multicast.</source>
        <translation>senza Multicast</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="63"/>
        <source>IP must be an IPv4 multicast address.
(224.0.0.0 to 239.255.255.255)</source>
        <translation>IP dev&apos;essere un Indirizzo IPv4 Multicast.
(224.0.0.0 a 239.255.255.255)</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="74"/>
        <source>IPv4-only.</source>
        <translation>Solo IPv4</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="78"/>
        <source>Packet Sender supports multicast when binded to IPv4. 
Turn off IPv6 and switch to IPv4 mode?</source>
        <translation>Packet Sender consente Multicast quando è vincolato a IPv4.
disattivare IPv6 e Cambiae la modalità a IPv4?</translation>
    </message>
</context>
<context>
    <name>PacketLogModel</name>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source>Data portion is </source>
        <translation>La porzione di Dati è </translation>
    </message>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source> bytes</source>
        <translation> bytes</translation>
    </message>
</context>
<context>
    <name>PacketNetwork</name>
    <message>
        <location filename="../packetnetwork.cpp" line="246"/>
        <source>Port bind error.</source>
        <translation>Errore a vincolare la porta</translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="250"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT], which is less than 1024. 

Privileged ports requires running Packet Sender with admin-level / root permissions.</source>
        <translation>Packet Sender ha tentato (e ha fallito) di vincolarsi alla Porta [PORT], che è inferiore a 1024.

Le Porte privilegiate richieste richiedono l&apos;esecuzione di Packet Sender con permessi di amministratore/root.</translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="251"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT].

 - Are you running multiple instances? 

 - Trying to bind to a missing custom IP?</source>
        <translation>Packet Sender ha tentato (e ha fallito) di vincolarsi alla Porta [PORT].

- Stai eseguendo più istanze?

- Stai provando a vincolarti ad un IP personalizzato che non è disponible?</translation>
    </message>
</context>
<context>
    <name>PanelGenerator</name>
    <message>
        <location filename="../panelgenerator.ui" line="20"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="56"/>
        <location filename="../panelgenerator.ui" line="69"/>
        <location filename="../panelgenerator.ui" line="82"/>
        <location filename="../panelgenerator.ui" line="95"/>
        <location filename="../panelgenerator.ui" line="108"/>
        <location filename="../panelgenerator.ui" line="121"/>
        <location filename="../panelgenerator.ui" line="134"/>
        <location filename="../panelgenerator.ui" line="147"/>
        <location filename="../panelgenerator.ui" line="160"/>
        <source>PushButton</source>
        <translation>PushButton</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="183"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="192"/>
        <source>&amp;Export</source>
        <translation>&amp;Esporta</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="203"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="209"/>
        <source>S&amp;ettings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="223"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="226"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="231"/>
        <source>Save &amp;As...</source>
        <translation>&amp;Salva come..</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="236"/>
        <source>&amp;Import Panels File</source>
        <translation>&amp;Importa File Pannelli</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="239"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="244"/>
        <source>Portable &amp;Windows Package</source>
        <translation>Pacchetto Partabile di Windows</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="247"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="252"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Documentazione</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="255"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="260"/>
        <source>Panel Name</source>
        <translation>Nome del Pannello</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="265"/>
        <source>Panel ID</source>
        <translation>ID del Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="273"/>
        <source>Starter Panel:</source>
        <translation>Pannello Iniziale:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="278"/>
        <location filename="../panelgenerator.cpp" line="48"/>
        <source>Delete Panel</source>
        <translation>Elimina Pannello</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="283"/>
        <source>&amp;Panels File</source>
        <translation>File di Pannello</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="288"/>
        <source>Portable &amp;macOS Package</source>
        <translation>Pacchetto di macOS Portabile</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="293"/>
        <source>Portable Linux Package</source>
        <translation>Pacchetto di Linux Portabile</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="298"/>
        <source>&amp;New Panel</source>
        <translation>Pannello Nuovo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="301"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="40"/>
        <source>Panels</source>
        <translation>Pannelli</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="47"/>
        <source>Load Panel</source>
        <translation>Carica Pannello</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="52"/>
        <location filename="../panelgenerator.cpp" line="364"/>
        <source>Viewing</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="135"/>
        <source>URL or File</source>
        <translation>URL o File</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="136"/>
        <source>URL or File:</source>
        <translation>URL o File:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="155"/>
        <source>Link text</source>
        <translation>Testo del Collegamento</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="156"/>
        <source>Link text:</source>
        <translation>Testo del Collegamento:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="321"/>
        <source>Confirm delete.</source>
        <translation>Conferma Eliminazione</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="325"/>
        <source>Delete </source>
        <translation>Elimina </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="331"/>
        <source>Deleting </source>
        <translation>Eliminando </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="339"/>
        <source>Panel </source>
        <translation>Pannello </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="341"/>
        <source>Set Panel Name: </source>
        <translation>Imposta il nome del Pannello: </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="342"/>
        <source>Set Panel ID: </source>
        <translation>Imposta ID del Pannello: </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="346"/>
        <source>Packet Sender Panel: New Panel</source>
        <translation>Pannello di Packet Sender: Pannello Nuovo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="347"/>
        <source>Set Panel Name: New Panel</source>
        <translation>Imposta Nome del Pannello: Pannello Nuovo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="348"/>
        <source>Set Panel ID: New Panel</source>
        <translation>Imposta ID del Pannello: Pannello Nuovo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="354"/>
        <source>Starter Panel: Yes</source>
        <translation>Pannello Iniziale: Si</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="356"/>
        <source>Starter Panel: No</source>
        <translation>Pannello Iniziale: No</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="359"/>
        <source>Editing</source>
        <translation>Editando</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="436"/>
        <source>Button </source>
        <translation>Pulsante </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="443"/>
        <source>(Button will be deleted)</source>
        <translation>(Il Pulsante sarà eliminato)</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="453"/>
        <source>Test</source>
        <translation>Prova</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="460"/>
        <source>Script is empty</source>
        <translation>Lo script è vuoto</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="522"/>
        <location filename="../panelgenerator.cpp" line="527"/>
        <source>New Button</source>
        <translation>Pulsante Nuovo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="692"/>
        <source>Nothing to do...</source>
        <translation>Nulla da fare...</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="694"/>
        <source>Executing </source>
        <translation>Eseguendo </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="699"/>
        <source>Unknown Command</source>
        <translation>Comando sconosciuto</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="769"/>
        <source>Transition Panel</source>
        <translation>Pannello di transizione</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>Tranisition to Panel &quot;</source>
        <translation>Transizione al pannello &quot;</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>&quot;?
This panel has not been saved. You may lose changes.</source>
        <translation>&quot;?
Pannello non Salvato. Potresti perdere i cambiamenti.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="785"/>
        <source>Not loading panel</source>
        <translation>Non sto caricando il pannello</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="789"/>
        <source>Not loading panel in edit mode</source>
        <translation>Non sto caricando il pannello nel modo editazione</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="905"/>
        <source>Change URL</source>
        <translation>Cambia URL</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="906"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="913"/>
        <source>Delete link</source>
        <translation>Elimina collegamento</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="917"/>
        <source>Delete URL link?
</source>
        <translation>Elimina collegamento URL?
</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="928"/>
        <source>Change Text</source>
        <translation>Cambia Testo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="929"/>
        <source>text:</source>
        <translation>Testo:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="990"/>
        <source>Panels File</source>
        <translation>File di pannelli</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="992"/>
        <source>*.panels</source>
        <translation>*.panels</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1029"/>
        <source>Unknown File</source>
        <translation>File sconosciuto</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1032"/>
        <source>This does not seem to be a valid PS Panels file</source>
        <translation>Non sembra essere un file PS di pannelli valido</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source>Found </source>
        <translation>Trovato </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <source> packets. Saving overwrites duplicate names.

Continue packet import?</source>
        <translation> pacchetti. Salvando si sovrascriveranno i nomi duplicati.

Continua esportazione dei pacchetti?</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source> panels. Ovewrite dpulicated IDs?

Selecting No will generate new IDs and append.</source>
        <translation> pannelli. Sovrascrivere gli ID duplicati?

        Seleziona No per generare nuovi ID e aggiungerli.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1143"/>
        <source>Coming soon.</source>
        <translation>prossimamente.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1160"/>
        <source>Change Name</source>
        <translation>Cambia Nome</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1161"/>
        <location filename="../panelgenerator.cpp" line="1209"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1177"/>
        <source>Change ID</source>
        <translation>Cambia ID</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1178"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1208"/>
        <source>New Name</source>
        <translation>Nome nuovo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1243"/>
        <source>Save PS Panels</source>
        <translation>Salva pannelli PS</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1244"/>
        <source>panels (*.panels)</source>
        <translation>pannelli (*.panels)</translation>
    </message>
</context>
<context>
    <name>PersistentConnection</name>
    <message>
        <location filename="../persistentconnection.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="26"/>
        <source>Waiting...</source>
        <translation>Attendi...</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="40"/>
        <source>Load</source>
        <translation>Carica</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="47"/>
        <source>Search Packets...</source>
        <translation>Cerca Pacchetti...</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="61"/>
        <source>Raw</source>
        <translation>Raw</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="71"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="84"/>
        <source>ASCII. Press Enter to Send.</source>
        <translation>ASCII. Premi ENTER per inviare.</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="94"/>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="104"/>
        <source>Append \r</source>
        <translation>Aggiungi \r</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="114"/>
        <location filename="../persistentconnection.cpp" line="468"/>
        <source>Send File</source>
        <translation>Invia File</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="158"/>
        <source>Clear Log</source>
        <translation>Cancella Log</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="165"/>
        <source>To Clipboard</source>
        <translation>Agli appunti</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="185"/>
        <source>Resending(1)</source>
        <translation>Reinviando(1)</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="154"/>
        <location filename="../persistentconnection.cpp" line="156"/>
        <source>You:</source>
        <translation>Tu:</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="470"/>
        <source>*.*</source>
        <translation>*.*</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="511"/>
        <source>Copied</source>
        <translation>Copiato</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="512"/>
        <source>Output sent to your clipboard</source>
        <translation>Uscita inviata agli appunti</translation>
    </message>
</context>
<context>
    <name>PersistentHTTP</name>
    <message>
        <location filename="../persistenthttp.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="44"/>
        <source>Copy Code</source>
        <translation>Copia Codice</translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="64"/>
        <source>.html View/Edit</source>
        <translation>Vedi/Edita</translation>
    </message>
</context>
<context>
    <name>PostDataGen</name>
    <message>
        <location filename="../postdatagen.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="22"/>
        <source>Key</source>
        <translation>Chiave</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="32"/>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="42"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="51"/>
        <source>Params</source>
        <translation>Parametri</translation>
    </message>
    <message>
        <location filename="../postdatagen.cpp" line="30"/>
        <source>Data Generator</source>
        <translation>Generatore di dati</translation>
    </message>
</context>
<context>
    <name>PreviewFilter</name>
    <message>
        <location filename="../mainwindow.cpp" line="2726"/>
        <source>Multi-line editor</source>
        <translation>Editor Multi Línea</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2732"/>
        <source>Update</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2733"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../packet.cpp" line="266"/>
        <location filename="../settings.cpp" line="44"/>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="267"/>
        <source>Send &lt;b&gt;</source>
        <translation>Invia &lt;b&gt;</translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="627"/>
        <source>Received an invalid MAC address</source>
        <translation>Ricevuto un indirizzo MAC non valido</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="47"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="50"/>
        <source>Resend</source>
        <translation>Reinvia</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="53"/>
        <source>To Address</source>
        <translation>A indirizzo</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="56"/>
        <source>To Port</source>
        <translation>A porta</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="59"/>
        <source>Method</source>
        <translation>Metodo</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="62"/>
        <source>Request Path</source>
        <translation>Percorso richiesto</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="65"/>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="68"/>
        <source>From IP</source>
        <translation>IP Iniziale</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="71"/>
        <source>From Port</source>
        <translation>Porta Iniziale</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="74"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="24"/>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="30"/>
        <source>Basic</source>
        <translation>Base</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="36"/>
        <source>Enable UDP Servers</source>
        <translation>Abilita Server UDP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="45"/>
        <source>UDP Server Ports (comma-separated, 0 for random)</source>
        <translation>Porte di Server UDP (separate da virgola, 0 per casuale)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="52"/>
        <location filename="../settings.ui" line="77"/>
        <location filename="../settings.ui" line="102"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="61"/>
        <source>Enable TCP Servers</source>
        <translation>Abilita Server TCP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="70"/>
        <source>TCP Server Port (comma-separated, 0 for random)</source>
        <translation>Porta del Server TCP (separati da virgola, 0 per casuale)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="86"/>
        <source>Enable SSL/TLS Servers</source>
        <translation>Abilita Server SSL/TLS</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="95"/>
        <source>SSL Server Port (comma-separated, 0 for random)</source>
        <translation>Porta del Server SSL (separati da virgola, 0 per casuale)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="111"/>
        <source>Set the server ports to 0 if you want to run multiple Packet Sender instances.</source>
        <translation>Imposta le porte del server a 0 se vuoi avviare più istanze di Packet Sender.</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="125"/>
        <source>Translate macros when sending</source>
        <translation>Traduci macro inviando</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="132"/>
        <source>Send a basic response with macro support</source>
        <translation>Invia una risposta base con supporto macro</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="141"/>
        <source>Response Data</source>
        <translation>Dati di Risposta</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="155"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="169"/>
        <location filename="../settings.ui" line="771"/>
        <location filename="../settings.ui" line="833"/>
        <location filename="../settings.ui" line="867"/>
        <location filename="../settings.ui" line="908"/>
        <location filename="../settings.ui" line="941"/>
        <source>HEX</source>
        <translation>HEX</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="197"/>
        <source>Additional UDP/TCP/SSL Settings</source>
        <translation>Configurazione aggiuntiva di UDP/TCP/SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="205"/>
        <source>IPv4 Only</source>
        <translation>Solo IPv4</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="218"/>
        <source>IPv6 Only</source>
        <translation>Solo IPv6</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="230"/>
        <source>Bind This:</source>
        <translation>Vincola questo:</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="240"/>
        <source>Your IP</source>
        <translation>Tuo indirizzo IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="260"/>
        <source>0.0 for off</source>
        <translation>0.0 per disabilitare</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="271"/>
        <source>Cancel Resending after # packets</source>
        <translation>Cancella reinvio dopo # pacchetti</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="278"/>
        <source>0 for off</source>
        <translation>0 per disabilitare</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="287"/>
        <source>Attempt Receive Before Send</source>
        <translation>Attendi ricezione prima di inviare</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="294"/>
        <source>500 ms delay after connect (slow devices)</source>
        <translation>Ritardo di 500 ms dopo la Connessione (dispositivi lenti)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="301"/>
        <source>Persistent TCP Connections</source>
        <translation>connessione TCP persistente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="308"/>
        <source>Resolve DNS during input (old method)</source>
        <translation>Risolvi DNS durante ricezione (metodo vecchio)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="315"/>
        <source>Ignore SSL Errors (Wrong host, expired, self-signed, etc)</source>
        <translation>Ignora errori di SSL (host non corretto, scaduto, self-signed, etc.)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="328"/>
        <source>SSL Server may use an internal snake oil cert</source>
        <translation>Il Server SSL può usare un certificato interno falso</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="337"/>
        <source>SSL CA Certificates</source>
        <translation>Certificato CA SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="344"/>
        <source>Path from where to load the CA certificats (leave empty for defaults)</source>
        <translation>Percorso dove caricare i certificati di CA (lascia in bianco per valori di default)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="351"/>
        <location filename="../settings.ui" line="376"/>
        <location filename="../settings.ui" line="401"/>
        <source>Browse</source>
        <translation>Naviga</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="362"/>
        <source>SSL Local Certificate</source>
        <translation>Certificato locale SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="369"/>
        <source>File path for the client side local certificate</source>
        <translation>Percorso File per il certificato locale lato cliente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="387"/>
        <source>SSL Private Key</source>
        <translation>Chiave Privata SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="394"/>
        <source>File path for the client side private key</source>
        <translation>Percorso File per la chiave privata lato cliente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="430"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="436"/>
        <source>Automatically adjust ContentType when sending XML or JSON</source>
        <translation>Imposta automaticamente il tipo di contenuto quando invia XML o JSON</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="458"/>
        <source>Generate Auth Header</source>
        <translation>Genera Header di autenticazione</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="469"/>
        <location filename="../settings.cpp" line="975"/>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="479"/>
        <source>Username/ClientID</source>
        <translation>Nome utente/ID Cliente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="489"/>
        <source>Password/AccessCode</source>
        <translation>Password/Codice di acceso</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="499"/>
        <location filename="../settings.cpp" line="1046"/>
        <source>HTTP Header</source>
        <translation>Header HTTP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="540"/>
        <source>Display</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="548"/>
        <source>Saved Packet Display Order (Drag and Drop)</source>
        <translation>Ordine di visualizzazione pacchetti Salvati (drag and drop)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="555"/>
        <location filename="../settings.ui" line="583"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="560"/>
        <location filename="../settings.ui" line="588"/>
        <source>To IP</source>
        <translation>A IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="565"/>
        <location filename="../settings.ui" line="593"/>
        <source>From IP</source>
        <translation>Da IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="576"/>
        <source>Traffic Log Display Order (Drag and Drop)</source>
        <translation>Ordine di visualizzazione del Log di Traffico (drag and drop)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="253"/>
        <source>Multi-Send Delay (sec)</source>
        <translation>Ritardo di invio multiplo (sec)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="530"/>
        <source>Delete Header</source>
        <translation>Elimina Header</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="601"/>
        <source>Use Default Order</source>
        <translation>Usa ordine di default</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="626"/>
        <source>Miscellaneous</source>
        <translation>Varie</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="632"/>
        <source>Use Dark Theme (requires restart)</source>
        <translation>Usa tema scuro (riavvio necessario)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="641"/>
        <source>Language (Requires Restart)</source>
        <translation>Lingua (riavvio necessario))</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="650"/>
        <source>Copy to Clipboard button uses raw data</source>
        <translation>Il pulsante copia negli appunti usa dati raw</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="657"/>
        <source>Rolling 100-entry traffic log</source>
        <translation>Log di Traffico Continuo di 100 line</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="664"/>
        <source>Restore previous session</source>
        <translation>Reimposta sessione precedente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="671"/>
        <source>Periodically check for updates</source>
        <translation>Controlla aggiornamenti periodicamente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="678"/>
        <source>Use ellipsis [...] for long data entries (helps performance)</source>
        <translation>Usa puntini sospensione [...] per sequenze di dati troppo lunghi (migliora performance)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="685"/>
        <source>Auto-Launch Starter Panel</source>
        <translation>Esegui automaticamente il pannello iniziale</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="722"/>
        <source>Smart Responses</source>
        <translation>Risposta intelligente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="730"/>
        <source>Send a Smart Response with Macro Support</source>
        <translation>Invia una risposta intelligente con supporto Macro</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="758"/>
        <source>Response 5</source>
        <translation>Risposta 5</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="766"/>
        <location filename="../settings.ui" line="828"/>
        <location filename="../settings.ui" line="862"/>
        <location filename="../settings.ui" line="903"/>
        <location filename="../settings.ui" line="936"/>
        <source>Mixed ASCII</source>
        <translation>ASCII misto</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="779"/>
        <location filename="../settings.ui" line="844"/>
        <location filename="../settings.ui" line="882"/>
        <location filename="../settings.ui" line="895"/>
        <location filename="../settings.ui" line="928"/>
        <source>Enable</source>
        <translation>Abilita</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="786"/>
        <source>Response 4</source>
        <translation>Risposta 4</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="793"/>
        <source>If Packet data equals</source>
        <translation>Se i dati del pacchetto sono uguali</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="800"/>
        <source>Reply with</source>
        <translation>Rispondi con</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="807"/>
        <source>Encoding</source>
        <translation>Codifica</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="814"/>
        <source>Response 1</source>
        <translation>Risposta 1</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="854"/>
        <source>Response 2</source>
        <translation>Risposta 2</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="875"/>
        <source>Response 3</source>
        <translation>Risposta 3</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="963"/>
        <source>Available macros: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}}</source>
        <translation>Macros disponibili: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}}</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="970"/>
        <source>Packet Sender will swap macro with a real value before sending</source>
        <translation>Packet Sender sostituirà le macro con i dati reali prima dell&apos;invio</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="981"/>
        <source>{{DATE}} format (Requires Restart)</source>
        <translation>{{DATE}} formato (Riavvio necessario)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="998"/>
        <location filename="../settings.ui" line="1039"/>
        <source>Example</source>
        <translation>Esempio</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1022"/>
        <source>{{TIME}} format (Requires Restart)</source>
        <translation>{{TIME}} formato (Riavvio necessario)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1083"/>
        <source>Online Documentation</source>
        <translation>Documentazione online</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="103"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="359"/>
        <source>Bad IP.</source>
        <translation>IP non valido</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="363"/>
        <source>Packet Sender cannot bind invalid IP </source>
        <translation>Packet Sender non può vincolarsi a un IP non valido</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="377"/>
        <source>TCP and SSL non-zero port conflict.</source>
        <translation>Conflitto di Porte TCP e SSL diverse da zero.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="381"/>
        <source>Packet Sender cannot bind TCP and SSL to the same port.</source>
        <translation>Packet Sender non può vincolare TCP e SSL alla stessa porta.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="726"/>
        <source>Open Directory</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Choose Cert</source>
        <translation>Seleziona Certificato</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Certs (*.pem)</source>
        <translation>Certificati (*.pem)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Choose Key</source>
        <translation>Scegli chiave</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Keys (*.key, *.pem)</source>
        <translation>chiavi (*.key, *.pem)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1044"/>
        <source>Key</source>
        <translation>chiave</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1045"/>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1040"/>
        <source>UN/ClientID</source>
        <translation>Nome utente/ID cliente</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1041"/>
        <source>PW/Access</source>
        <translation>Password/Codice di acceso</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1042"/>
        <source>HTTP Auth Header</source>
        <translation>HTTP Header di autenticazione</translation>
    </message>
</context>
<context>
    <name>SubnetCalc</name>
    <message>
        <location filename="../subnetcalc.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="26"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="33"/>
        <source>IPv4 address</source>
        <translation>Indirizzo IPv4</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="44"/>
        <source>Subnet</source>
        <translation>Subnet</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="51"/>
        <source>Dotted or number of bits </source>
        <translation> Punteggiato o numero di bit</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="66"/>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="76"/>
        <source>Calculated Start..</source>
        <translation>Inizio calcolato..</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="87"/>
        <source>End</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="97"/>
        <source>Calculated End...</source>
        <translation>Fine calcolata...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="108"/>
        <source>Broadcast</source>
        <translation>Broadcast</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="118"/>
        <source>Broadcast...</source>
        <translation>Broadcast...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="133"/>
        <source>Within subnet check</source>
        <translation>Interno alla verifica Subnet</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="140"/>
        <source>IP Address...</source>
        <translation>Indirizzo IP...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="156"/>
        <source>Subnet Check Result...</source>
        <translation>Risultato della verifica Subnet...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="168"/>
        <source>Results log...</source>
        <translation>Log dei risultati...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="177"/>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="24"/>
        <source>IPv4 Subnet Calculator</source>
        <translation>Calcolatrice Subnet IPv4</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="26"/>
        <source>Your non-loopback addresses: 

</source>
        <translation>Tuo indirizzo non-loopback:

</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="263"/>
        <source>Within </source>
        <translation>Interno a </translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="273"/>
        <source>No entries in subnet.</source>
        <translation>Nessun valore di subnet.</translation>
    </message>
</context>
<context>
    <name>UDPFlooding</name>
    <message>
        <location filename="../udpflooding.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="24"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="38"/>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="54"/>
        <source>Ascii</source>
        <translation>Ascii</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="76"/>
        <source>Delay (ms)</source>
        <translation>Ritardo (ms)</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="86"/>
        <source>Speed (MB/s)</source>
        <translation>Velocità (MB/s)</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="101"/>
        <source>0 or blank is no delay or max speed</source>
        <translation>0 o vuoto significa nessun ritardo o velocità massima</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="110"/>
        <source>Start</source>
        <translation>Inizia</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="117"/>
        <source>Stop</source>
        <translation>Ferma</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="139"/>
        <source>Waiting to send...</source>
        <translation>Attendi ad inviare...</translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="25"/>
        <source>UDP Traffic Generator (Experimental)</source>
        <translation>Generatore di Traffico UDP (Sperimentale)</translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="76"/>
        <location filename="../udpflooding.cpp" line="81"/>
        <source>Invalid</source>
        <translation>non valido</translation>
    </message>
</context>
<context>
    <name>WakeOnLAN</name>
    <message>
        <location filename="../wakeonlan.ui" line="14"/>
        <source>Wake-On-LAN</source>
        <translation>Wake-On-LAN</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="22"/>
        <source>Target MAC</source>
        <translation>MAC di destinazione</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="29"/>
        <source>01:23:45:67:89:ab</source>
        <translation>01:23:45:67:89:ab</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="36"/>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="59"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="68"/>
        <source>9</source>
        <translation>9</translation>
    </message>
</context>
</TS>
